#
# spec file for package libXvMC
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXvMC
%define lname	libXvMC1
Version:        1.0.14
Release:        1.4
Summary:        X-Video Motion Compensation library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXvMC
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXvMC/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xv)

%description
X-Video Motion Compensation (XvMC), is an extension of the X video
extension (Xv) for the X Window System. The XvMC API allows video
programs to offload portions of the video decoding process to the GPU
video-hardware.

%package -n %lname
Summary:        X-Video Motion Compensation library
Group:          System/Libraries

%description -n %lname
X-Video Motion Compensation (XvMC), is an extension of the X video
extension (Xv) for the X Window System. The XvMC API allows video
programs to offload portions of the video decoding process to the GPU
video-hardware.

The supported portions to be offloaded by XvMC onto the GPU are
motion compensation (mo comp) and inverse discrete cosine transform
(iDCT) for MPEG-2 video. XvMC also supports offloading decoding of mo
comp, iDCT, and VLD (Variable-Length Decoding) for MPEG-2/MPEG-4-ASP.

%package devel
Summary:        Development files for the X-Video Motion Compensation library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Conflicts:      xorgproto-devel < 2019.2
Provides:       xorgproto-devel:%{_includedir}/X11/extensions/vldXvMC.h

%description devel
X-Video Motion Compensation (XvMC), is an extension of the X video
extension (Xv) for the X Window System. The XvMC API allows video
programs to offload portions of the video decoding process to the GPU
video-hardware.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
rm -f "%buildroot/%_libdir"/*.a
mkdir -p %buildroot/%_docdir/%name
mv %buildroot/%{_datadir}/doc/%name \
   %buildroot/%{_docdir}/%name

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libXvMC*.so.1*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXvMC*.so
%_libdir/pkgconfig/xvmc.pc
%_libdir/pkgconfig/xvmc-wrapper.pc
%_docdir/%name

%changelog
* Mon Feb  5 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.14
  * Make doc install path from meson match autotools
  * gitlab CI: add a basic build test
  * gitlab CI: Add libtool to required packages
  * gitlab CI: stop requiring Signed-off-by in commits
  * configure: Use LT_INIT from libtool 2 instead of deprecated AC_PROG_LIBTOOL
  * Convert to X.Org standard code style
  * Variable scope reductions as recommended by cppcheck
  * Replace custom copy of GetReq macro with call to Xlib 1.5's _XGetRequest
  * Handle implicit conversion warnings from clang
- switched to meson build system
* Sat Mar 26 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.13
  * autotools: fix Requires and Requires.Private in pkgconfig
  * meson: Add a meson build system
  * meson: Fix typo
  * editorconfig: add meson
  * Fix spelling/wording issues
  * Build xz tarballs instead of bzip2
- supersedes n_bring-back-libXv-dep.patch
* Sun Oct 20 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add conflicts for old xorgproto-devel, X11/extensions/vldXvMC.h
  was moved to libXvMC-devel.
* Mon Sep 30 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.12
  * This release fixes the pkgconfig data to not refer to libXv,
    adds a pkgconfig file for libXvMCW, and prepares for a future
    xorgproto release. There should be no functional changes.
- n_bring-back-libXv-dep.patch
  * fixes build of Mesa's xvmc gallium driver, since that
    references in XvMCCreateContex also XvQueryAdaptors,
    XvFreeAdaptorInfo and XvFreeAdaptorInfo
* Fri Mar 22 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.11
  * autogen: add default patch prefix
  * autogen.sh: use quoted string variables
  * autogen.sh: use exec instead of waiting for configure to finish
  * Update configure.ac bug URL for gitlab migration
  * Need to check for -1, not 0, to determine if shmat() failed
  * Fix sign comparison warnings for loop indexes
  * Fix handling of shmKey in XvMCGetDRInfo
  * Update README for gitlab migration
* Fri Oct 28 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.10:
  + Avoid buffer underflow on empty strings.
* Sat Mar 21 2015 sndirsch@suse.com
- added baselibs.conf as source to specfile
* Fri Mar 20 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.9:
  + Require ANSI C89 pre-processor, drop pre-C89 token pasting support
  + Rename local err variable in XW_RSYM macro to avoid shadow warnings
  + Remove fallback for _XEatDataWords, require libX11 1.6 for it
  + Fix linking with -Wl,--no-undefined on Linux
* Fri Jun 14 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.8:
  This bug fix release provides the fixes for the recently announced security
  issues CVE-2013-1990 & CVE-2013-1999, and the fixes for the bugs introduced
  in the initial set of patches for those security issues.
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.0.7:
  + Janitorial cleanups
  + Build configuration improvements
* Tue Feb  7 2012 jengelh@medozas.de
- Split xorg-x11-libs into separate packages
